import sys
import typing

GenericType = typing.TypeVar("GenericType")


def log2vis(msgs, settings):
    ''' 

    '''

    pass


def protect_format_seq(msg):
    ''' 

    '''

    pass
